Probability theoretic inequality | Physics Forums - The Fusion of Science and Community
Description: Can anyone help me prove under what conditions on the distance function d(x_1,x_2) the following inequality holds for any two probability distributions...

- Forums
  - Search Forums
  - Recent Posts
  - Unanswered Threads
- Videos
- Members
  - Notable Members
  - Current Visitors
  - Recent Activity
  - New Profile Posts
- Insights
- Search

### Log in or Sign up

Dismiss Notice
Join Physics Forums Today!
The friendliest, high quality science and math community on the planet! Everyone who loves science is here!

# Probability theoretic inequality

1. Jul 21, 2008 #1

   ### winterfors

   ###

   > Can anyone help me prove under what conditions on the distance function [tex]d(x_1,x_2)[/tex] the following inequality holds for any two probability distributions (represented by probability densities) [tex]p(x)[/tex] and [tex]q(x)[/tex] :
   > [tex]2\int{\int{d^2(x_1,x_2)p(x_1)q(x_2)dx_1dx_2}
   > \geq
   > \int{\int{d^2(x_1,x_2)p(x_1)p(x_2)dx_1dx_2} +
   > \int{\int{d^2(x_1,x_2)q(x_1)q(x_2)dx_1dx_2}
   > [/tex]
   > where [tex]d^2(x_1,x_2)[/tex] is the squared distance between [tex]x_1[/tex] and [tex]x_2[/tex] in some metric space [tex]\Theta[/tex]. All integrals are over [tex]\Theta[/tex].
   > One can easily verify by insertion that the inequality holds for a Euclidian metric where [tex]d^2(x_1,x_2)=(x_1-x_2)^2[/tex], with equality if and only if the expectation of [tex]p(x)[/tex] and [tex]q(x)[/tex] are the same.
   > It must surely hold for some more general class of metrics (described by [tex]d^2(x_1,x_2)[/tex]) - possibly all metrics - but I've so far failed to demonstrate it. Does anyone have an idea of how to prove it in some more general case?

   winterfors, Jul 21, 2008
2. Phys.org - latest science and technology news stories on Phys.org
   - • Game over? Computer beats human champ in ancient Chinese game
   - • Simplifying solar cells with a new mix of materials
   - • Imaged 'jets' reveal cerium's post-shock inner strength

Show Ignored Content
Know someone interested in this topic? Share this thread via Reddit, Google+, Twitter, or Facebook
Can you offer guidance or do you also need help?
Draft saved Draft deleted
The Diffraction Limited Spot Size with Perfect Focusing
Test Your NASA Knowledge
Entanglement Entropy – Part 1: Quantum Mechanics
What Is The Most Important Thing That You Learned?
Relativity Variables: Velocity, Doppler-Bondi k, and Rapidity
Interview with a Theoretical Physicist: Sabine Hossenfelder
Frames of Reference: Linear Acceleration View
Trick to Solving Integrals Involving Tangent and Secant
The Pantheon of Derivatives – Part III
Computer Language Primer – Part 1
Very Little Excuse To Ask A Question Cold

  Similar Discussions: Probability theoretic inequality

1. ### Probability inequality for the sum of independent normal random variables (Replies: 3)

2. ### A basic probability inequality (Replies: 2)

3. ### Probability of a probability (Replies: 4)

4. ### Empirical and theoretical probability (Replies: 0)

5. ### Conflict between experimental and theoretical probability results (Replies: 5)

Loading...

- Log in with Facebook
- Log in with Twitter

Your name or email address:

Do you already have an account?
  - No, create an account now.
  - Yes, my password is:
  - Forgot your password?

  Stay logged in